fit_cum_simple: Calculate normalized cumulative sum for top N elements of a...

View source: R/cumulative_percentage.R

fit_cum_simpleR Documentation

Calculate normalized cumulative sum for top N elements of a numeric vector

Description

Calculate normalized cumulative sum for top N elements of a numeric vector

Usage

fit_cum_simple(x)

Arguments

x

Non-empty numeric vector (integration site ratio data)

Value

Named vector of cumulative sums for predefined target indices + total sum (all = 1)


lisat documentation built on March 27, 2026, 5:07 p.m.