View source: R/cumulative_percentage.R
| fit_cum_simple | R Documentation |
Calculate normalized cumulative sum for top N elements of a numeric vector
fit_cum_simple(x)
x |
Non-empty numeric vector (integration site ratio data) |
Named vector of cumulative sums for predefined target indices + total sum (all = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.